<?php
/*=====================*/
/*=== Pagespeed SEO ===*/
/*=====================*/
// CSS préchargés (preload) pour éviter les chargements critiques
function preload_stylesheet_css($html, $handle, $href, $media) {
	if(is_admin()) {
		return $html;		
	}
	return '<link rel="preload" href="'.$href.'" as="style" id="'.$handle.'" media="'.$media.'" onload="this.onload=null;this.rel=\'stylesheet\'">';
}
add_filter('style_loader_tag', 'preload_stylesheet_css', 10, 4);

// Charge le CSS général en inline
function load_style_css_inline() {
	// N'applique la fonction qu'au front-end
	if(is_admin()) {
		return;
	}

	/*======================*/
	/*=== Chargement CSS ===*/
	/*======================*/
	// Chargement des styles à rendre "inline"
	$fusion = "";
	$css_array = array(
		get_bloginfo('stylesheet_url'), // Style par défaut du thème
	);

	// On parcoure le tableau et indente les CSS
	foreach($css_array as $css) {
		$fusion.= file_get_contents($css);
	}

	/*=======================*/
	/*=== Compression CSS ===*/
	/*=======================*/
	// Suppression automatique des commentaires
	$fusion = preg_replace('!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $fusion);

	// Suppression des espaces (...) avec les propriétés CSS
	$fusion = str_replace("('", "(", $fusion);
	$fusion = str_replace("')", ")", $fusion);
	$fusion = str_replace('("', '(', $fusion);
	$fusion = str_replace('")', ')', $fusion);
	$fusion = str_replace(' {', '{', $fusion);
	$fusion = str_replace('} ', '}', $fusion);
	$fusion = str_replace(': ', ':', $fusion);
	$fusion = str_replace('; ', ';', $fusion);

	// Suppression des espaces doubles, sauts de lignes, etc.
	$fusion = str_replace(array("\n", "\t", "\r", '  ', '    ', '    '), '', $fusion);

	// Suppression des derniers points-virgules (inutiles)
	$fusion = str_replace(';}', '}', $fusion);

	/*======================*/
	/*=== Adaptation URL ===*/
	/*======================*/
	// Rétablit les bons chemins d'URL quand c'est possible
	preg_match_all("|url\(([^)]+)\)|i", $fusion, $out);
	foreach($out[1] as $url) {
		if(substr($url, 0, 1) == "/") {
			$url = substr($url, 1);
		}

		if(preg_match("|(wp-content/theme)|i", $url) == false) {
			$fusion = str_replace($url, get_stylesheet_directory_uri().'/'.$url, $fusion);
		}
	}

	/*========================*/
	/*=== Affichage inline ===*/
	/*========================*/
	echo '<style>'.$fusion.'</style>';
}
add_action('wp_head', 'load_style_css_inline');
?>